/*
 *   Copyright 2010 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package net.brutex.xservices.ws;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import net.brutex.xservices.types.HostConnection;
import net.brutex.xservices.types.HostinfoType;
import net.brutex.xservices.types.MailMimeType;
import net.brutex.xservices.types.ReturnCode;
import net.brutex.xservices.types.ant.FileSetResource;
import net.brutex.xservices.util.BrutexNamespaces;

import org.apache.cxf.aegis.type.java5.XmlElement;
import org.apache.cxf.aegis.type.java5.XmlReturnType;
import org.apache.cxf.annotations.WSDLDocumentation;

/**
 *
 * @author Brian Rosenberger, bru@brutex.de
 * @since 0.4.0
 */
@WebService(targetNamespace = BrutexNamespaces.WS_XSERVICES)
@WSDLDocumentation("Various service operations.")
public interface MiscService {

    
    
    /**
     * @param hostname
     * @return ReturnCode
     */
    @WebMethod(operationName = "getHostinfo")
    @WSDLDocumentation(value = "Get information about a host.")
    public HostinfoType getHostinfo(
    		@WebParam(name = "hostname") @XmlElement(minOccurs="1", nillable=false ) String hostname);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param subject
     * @param message
     * @return ReturnCode
     */
    @WebMethod(operationName = "sendMailSimple")
    @WSDLDocumentation(value = "Send an email (simple).")
    public ReturnCode sendMailSimple(
    		@WebParam(name = "mailhost") @XmlElement(minOccurs="1", nillable=false) HostConnection mailhost,
            @WebParam(name = "from") @XmlElement(minOccurs="1", nillable=false) String from,
            @WebParam(name = "to") @XmlElement(minOccurs="1", nillable=false) String tolist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "message") String message);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param subject
     * @param message
     * @param res
     * @return ReturnCode
     */
    @WebMethod(operationName = "sendMailSimpleWithAttachment")
    @WSDLDocumentation(value = "Send an email with attachment (simple).")
    public ReturnCode sendMailSimpleWithAttachment(
    		@WebParam(name = "mailhost") @XmlElement(minOccurs="1", nillable=false) HostConnection mailhost,
            @WebParam(name = "from") @XmlElement(minOccurs="1", nillable=false) String from,
            @WebParam(name = "to") @XmlElement(minOccurs="1", nillable=false) String tolist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "message") String message,
            @WebParam(name = "attachments") FileSetResource res);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param cclist
     * @param bcclist
     * @param subject
     * @param mimetype
     * @param charset
     * @param message
     * @param res
     * @param ssl
     * @param tls
     * @return ReturnCode
     */
    @WebMethod(operationName = "sendMail")
    @WSDLDocumentation(value = "Send an email (advanced).")
    public ReturnCode sendMail(
    		@WebParam(name = "mailhost") @XmlElement(minOccurs="1", nillable=false) HostConnection mailhost,
            @WebParam(name = "from") @XmlElement(minOccurs="1", nillable=false) String from,
            @WebParam(name = "to") @XmlElement(minOccurs="1", nillable=false) String tolist,
            @WebParam(name = "cc") String cclist,
            @WebParam(name = "bcc") String bcclist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "mimetype") MailMimeType mimetype,
            @WebParam(name = "charset") String charset,
            @WebParam(name = "message") String message,
            @WebParam(name = "attachments") FileSetResource res,
            @WebParam(name = "useSSL") boolean ssl,
            @WebParam(name = "useStartTLS") boolean tls);

    /**
     *
     * @param minutes
     * @param seconds
     * @return ReturnCode
     */
    @WebMethod(operationName = "sleep")
    @WSDLDocumentation(value = "Delay request response a specified duration.")
    public ReturnCode sleep(
    		@WebParam(name = "minutes") int minutes,
            @WebParam(name = "seconds") int seconds);
    
    
    /**
     * @return ReturnCode
     */
    @WebMethod(operationName = "getInfo")
    @WSDLDocumentation(value = "Get XService information.")
    public ReturnCode getInfo();
    
    /**
     * Generate a UUID
     * @return new UUID
     */
    @WebMethod(operationName = "generateUUID")
    @WSDLDocumentation(value = "Generate a UUID.")
    public String generateUUID();
    
}
